@@ -4,11 +4,11 @@ void password(struct struc_bootmanager *btmgr, int recnum, char *password)
 {
     if (recnum==-2) /* root password */
     {
-	btmgr->sbmkdata.root_password=passcreator(password);
+	btmgr->sbmkdata.root_password=passcreator((unsigned char*) password);
     }
     else if (reccheck(btmgr->sbmkdata.boot_records[recnum]))
     {
-        btmgr->sbmkdata.boot_records[recnum].password=passcreator(password);
+        btmgr->sbmkdata.boot_records[recnum].password=passcreator((unsigned char*) password);
     }
     else
     {
